#ifndef _OET_H_
#define _OET_H_

#ident "@(#)$Header:   J:/usr/project/oet/uw2/src/oet.h_v   1.0   06 Nov 1996  9:11:20   hha  $"

#define OET_VERSION	1
#define OET_RELEASE	1
#define OET_ECO		'0'	/* ECO level */
#define OETLABEL	"1.1"	/* Global Version Label */

#ident "@!#!OET UNIX DRIVER 1.1"

#define OS_VERSION	SVREL42

#ifndef OLD_TYPES_INCLUDE
#define OLD_TYPES_INCLUDE
#include <sys/types.h>
#endif
#include <sys/stream.h>
#include <sys/strstat.h>

#include <sys/socket.h>
#include <net/if.h>
#include <net/strioc.h>
#include <sys/sockio.h>
#include <net/if_arp.h>

#include <sys/dlpi.h>

#ifndef __STDC__
#define const		/*EMPTY*/
#define volatile	/*EMPTY*/
#define void		int
#endif

#define MACADDRSIZE	(6)		/* Size in bytes of a MAC level address */
#define NULL_MACADDR	{0,0,0,0,0,0}

struct oethwconf {
	int  oc_link;						/* Use link with twisted pair */
	int  oc_media;						/* MEDIA to use */
	int  oc_speed;						/* Select speed to use */
	int  oc_duplex;						/* Select duplex to use */
	int  oc_latency;					/* PCI Latency timer */
	unsigned char oc_addr[MACADDRSIZE];	/* overwrite nodeaddress */
};

/* MEDIA selection only have effect on OC-218x adapters
*/
#define OET_MEDIA_ADAPTER	-1		/* Use adapter setting */
#define OET_MEDIA_AUTO		0		/* AUTO select media */
#define OET_MEDIA_FORCE_TP	1		/* Force use of twisted pair */
#define OET_MEDIA_FORCE_BNC	2		/* Force use of BNC */
#define OET_MEDIA_FORCE_AUI	3		/* Force use of AUI */

/* SPEED may take three values AUTO, 10Mb or 100Mb
   10Mb/100Mb will force the adapter in 10Mb/100Mb mode
   AUTO will select witch ever is best */
#define OET_SPEED_ADAPTER	-1		/* Use adapter setting */
#define OET_SPEED_AUTO		0		/* AUTO select speed */
#define OET_SPEED_FORCE10	1		/* force use of 10Mb */
#define OET_SPEED_FORCE100	2		/* force use of 100Mb */

/* DUPLEX may take three values AUTO, Half or Full
   Half/Full will force the adapter in Half/Full duplex mode
   AUTO will select witch ever is best */
#define OET_DUPLEX_ADAPTER		-1		/* Use adapter setting */
#define OET_DUPLEX_AUTO			0		/* AUTO select duplex */
#define OET_DUPLEX_FORCEHALF	1		/* force use of half duplex */
#define OET_DUPLEX_FORCEFULL	2		/* force use of full duplex */

/* LANETCY may take any value between zero and 255,
   NOTE that zero has a special meaning and should normally be used */
#define OET_LATENCY_DEFAULT	0	/* use the system assigned value */

/* Device filenames */
#define OETDEV_FMT	"/dev/oet_%d"	/* Clone device for adapter %d */
#define OETDEV0		"/dev/oet_0"	/* Clone device for adapter 0 */
#define OETDEV1		"/dev/oet_1"	/* Clone device for adapter 1 */
#define OETDEV2		"/dev/oet_2"	/* Clone device for adapter 2 */
#define OETDEV3		"/dev/oet_3"	/* Clone device for adapter 3 */
#define OETDEV4		"/dev/oet_4"	/* Clone device for adapter 4 */

typedef unsigned short lsap_t;		/* Link level Service access point (as seen from DLPI/LLI */

#pragma pack(1)
struct dlsap {
	unsigned char dls_mac[MACADDRSIZE];
	lsap_t dls_sap;
};
#pragma pack()
typedef struct dlsap dlsap_t;

#define LSAP_SIZE	sizeof(lsap_t)
#define DLSAP_SIZE	sizeof(dlsap_t)

/*
 *	MAC level ioctl-calls for network STREAMS drivers.
 *
 *		This is an additional interface to DLPI (LLI),
 *		which specifies some special ioctl(2) calls directly
 *		to the driver.
 *
 *	Based on a proposel by LACHMAN/RETIX/SCO.
 */

#ifndef MACIOC
#define MACIOC(x)		(('M' << 8) | (x))
#define MACIOC_DIAG		MACIOC(1)	/* Set diagnostic mode */
#define MACIOC_UNIT		MACIOC(2)	/* Unit select */
#define MACIOC_SETMCA		MACIOC(3)	/* Multicast setup */
#define MACIOC_DELMCA		MACIOC(4)	/* Multicast delete */
#define MACIOC_DELAMCA		MACIOC(5)	/* Flush multicast table */
#define MACIOC_GETMCA		MACIOC(6)	/* Get multicast table */
#define MACIOC_GETIFSTAT	MACIOC(7)	/* Dump statistics */
#define MACIOC_GETADDR		MACIOC(8)	/* Get MAC address */
#define MACIOC_SETADDR		MACIOC(9)	/* Set MAC address */
#define MACIOC_GETSTAT		MACIOC(10)	/* Get MS MAC statistics */
#define MACIOC_PROMISC		MACIOC(11)	/* Set Promiscuous Reception */
#define MACIOC_GETRADDR		MACIOC(12)	/* Get factory MAC Address */
#define MACIOC_CLRSTAT		MACIOC(13)	/* Clear MAC statistics */
#define MACIOC_GETMCSIZ		MACIOC(14)	/* Get multicast table size */
#define MACIOC_HWDEPEND		MACIOC(15)	/* Hardware dependent */

/*
 * We have to split the driver statistics into several ioctl(2) calls,
 * because a STREAMS control message in limited to 1024 bytes in size.
 */
#define MACIOC_LOCALSTAT	MACIOC(254)	/* local statistics */


#ifndef DL_AUTO_XID
#define DL_AUTO_XID		0x01		/* provider will respond to XID */
#define DL_AUTO_TEST		0x02		/* provider will respond to TEST */
#endif /* !DL_AUTO_XID */

#ifndef DL_PROMISC_PHYS
#define DL_PROMISC_PHYS		0x01		/* promiscuous mode at phys level */
#define DL_PROMISC_SAP		0x02		/* promiscuous mode at sap level */
#define DL_PROMISC_MULTI	0x03		/* promiscuous mode for multicast */
#endif /* !DL_PROMISC_PHYS */

/* statistics structure (for the MACIOC_GETSTAT ioctl) */
typedef struct mac_stats {
	unsigned long mac_frame_xmit;	/* Frames Transmitted */
	unsigned long mac_bcast_xmit;	/* Broadcast Frames Transmitted */
	unsigned long mac_mcast_xmit;	/* Multicast Frames Transmitted */
	unsigned long mac_lbolt_xmit;	/* Frames Transmitted per Second */
	unsigned long mac_frame_recv;	/* Frames Received */
	unsigned long mac_bcast_recv;	/* Broadcast Frames Received */
	unsigned long mac_mcast_recv;	/* Multicast Frames Received */
	unsigned long mac_lbolt_recv;	/* Frames Received per Second */
	unsigned long mac_frame_def;	/* Frames Deferred */
	unsigned long mac_collisions;	/* Total Collisions */
	unsigned long mac_frame_coll;	/* Frames Involved in a Collision */
	unsigned long mac_oframe_coll;	/* Out of Frame Collisions */
	unsigned long mac_xs_coll;	/* Dropped Due To Excess Collisions */
	unsigned long mac_frame_nosr;	/* Dropped Due To Lack of STREAMS */
	unsigned long mac_no_resource;	/* Dropped Due To Lack of Resources */
	unsigned long mac_badsum;	/* Bad Checksum Received */
	unsigned long mac_align;	/* Bad Alignment Received */
	unsigned long mac_badlen;	/* Bad Length Received */
	unsigned long mac_badsap;	/* Bad SAP Received */
	unsigned long mac_mcast_rjct;	/* Multicast Frames Rejected */
	unsigned long mac_carrier;	/* Errors Due To Lost Carrier */
	unsigned long mac_badcts;	/* Errors Due To Lost CTS */
	unsigned long mac_baddma;	/* Errors Due To Over/Under Runs */
	unsigned long mac_timeouts;	/* Device Timeouts */
	unsigned long mac_intr;		/* Device Interrupts */
	unsigned long mac_spur_intr;	/* Spurious Interrupts */
	unsigned long mac_ioctets;	/* received octets */
	unsigned long mac_ooctets;	/* transmitted octets */
	unsigned long mac_ifspeed;	/* net interface speed in bits/sec */
	unsigned long mac_reserved[1];	/* Reserved */
} mac_stats_t;

#endif /* MACIOC */

/* Adapter types */
#define ADPTYPE_PCI2325		1
#define ADPTYPE_PCI218x		2
#define NADPTXT		3	/* Number of adapter texts in oet_productname */


#define LLCSAP(X)	((X) & 0xFF)				/* Convert DLSAP to LLCSAP */
#define DLSAP(X)	((lsap_t)(((lsap_t)(X)) | ((lsap_t)0xFFFFFF00)))	/* Convert LLCSAP to DLSAP */

/* Some wellknown (?) IEEE lsap's */
#define LSAP_NULL	((lsap_t)0)		/* Nonexistsing lsap ? */
#define SAP_NETMAN	(0x00)			/* Network management SAP */
#define SAP_NULL	(0x00)
#define LSAP_NETMAN	DLSAP(SAP_NETMAN)
#define SAP_SNA		(0x04)			/* IBM SNA protocol */
#define LSAP_SNA	DLSAP(SAP_SNA)
#define SAP_GRPSNA	(0x04)			/* IBM group SNA protocol */
#define LSAP_GRPSNA	DLSAP(SAP_GRPSNA)
#define SAP_DODIP	(0x06)			/* DoD IP network protocol (Used by HP ?) */
#define LSAP_DODIP	((lsap_t)0x00000800)
#define SAP_NOVELL	(0x11)			/* NOVELL-ISO */
#define LSAP_NOVELL	DLSAP(SAP_NOVELL)
#define SAP_IPX		(0xE0)			/* NOVELL IPX protocol */
#define LSAP_IPX	((lsap_t)SAP_IPX)	/* SCO/Novell IPX/SPX */
#define LSAP_IPX_8023	((lsap_t)0x000000FF)	/* For LLC "nets" */
#define LSAP_IPX_ETH	((lsap_t)0x00008137)	/* Only for "real" ethernets */
#define IPX_FUADDR	((unsigned long)0x00800000)
#define SAP_NETBIOS	(0xF0)			/* PC NETBIOS protocol */
#define LSAP_NETBIOS	DLSAP(SAP_NETBIOS)
#define NETBIOS_FUADDR	((unsigned long)0x00000080)
#define SAP_GRPNETBIOS	(0xF1)			/* PC NETBIOS Group protocol */
#define LSAP_GRPNETBIOS	DLSAP(SAP_GRPNETBIOS)
#define SAP_ISO_CLTS	(0xFE)			/* ISO network protocol */
#define LSAP_ISO_CLTS	DLSAP(SAP_ISO_CLTS)
#define SAP_MSNETBEUI	SAP_NETBIOS		/* Microsoft Netbeui */
#define LSAP_MSNETBEUI	DLSAP(0xFE) 		/* ? what about ISO_CLTS */
#define MSNETBEUI_FUADDR ((unsigned long)0x00000080)
#define SAP_ISO_COTS	(0x7E)			/* ISO COTS/X.25 */
#define LSAP_ISO_COTS	DLSAP(SAP_ISO_COTS)
#define SAP_GLOB	(0xFF)			/* Global SAP */
#define LSAP_GLOB	DLSAP(SAP_GLOB)		/* Generic LLC protocol layer */
#define LSAP_ARP	((lsap_t)0x00000806)
#define LSAP_RARP	((lsap_t)0x00008035)
#define LSAP_PUP	((lsap_t)0x00000200)
#define SAP_SNAP	(0xAA)			/* Special SNAP protocol from RFC 1042 */
#define IP_FUADDR	((unsigned long)0x00040000) /* IETF Draft from Pusateri */
#define SAP_BANYAN	(0xBC)			/* BANYAN VINES IP ? */
#define LSAP_BANYAN	DLSAP(SAP_BANYAN)
#define SAP_STP		(0x42)			/* Spanning tree algorithm */
#define LSAP_STP	DLSAP(SAP_STP)
#define SAP_LRM		(0xF4)			/* LRM protocol */
#define LSAP_LRM	DLSAP(SAP_LRM)
#define LRM_FUADDR	((unsigned long)0x00000100)

#define SAP_TOPNBIOS	(0xF1)			/* TopNetBIOS protocol */
#define LSAP_TOPNBIOS	DLSAP(SAP_TOPNBIOS)
#define SAP_TOPN	(0xEC)			/* TopNetBIOS protocol, CO mode */
#define TOPNBIOS_FUADDR ((ulong)0x00380000)

#endif /* _OET_H_ */
